@@ -78,6 +78,7 @@ void ScilabSession::login()
      * QObject::connect(m_process, SIGNAL(readyReadStandardError()), SLOT (readError()));
      */
 
+
     m_process->start();
 
     if(ScilabSettings::integratePlots())
@@ -257,9 +258,9 @@ QSyntaxHighlighter* ScilabSession::syntaxHighlighter(QTextEdit* parent)
     return new ScilabHighlighter(parent);
 }
 
-Cantor::CompletionObject* ScilabSession::completionFor(const QString& command)
+Cantor::CompletionObject* ScilabSession::completionFor(const QString& command, int index)
 {
-    return new ScilabCompletionObject(command, this);
+    return new ScilabCompletionObject(command, index, this);
 }
 
 #include "scilabsession.moc"
